@@ -2,6 +2,10 @@
 # vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
 # Author: "Chris Ward <cward@redhat.com>
 
+'''
+Base cube for extracting data from SQL TEIID interface
+'''
+
 from psycopg2 import DatabaseError
 from metrique.cubes.basesql import BaseSql
 from metrique.sql.teiid import TEIID
@@ -19,12 +23,6 @@ DEFAULT_CONFIG = {
 class BaseTEIID(BaseSql):
     '''
     Driver which adds support for TEIID based sql cubes.
-
-    Overrides:
-        * connection parameters passed to __init__
-         - adds vdb
-        * proxy property, which connects using TEIID
-          driver instead of default SQL driver
     '''
     def __init__(self, db, host=None, vdb=None, port=None,
                  username=None, password=None, **kwargs):
