@@ -2,6 +2,16 @@
 # vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
 # Author: "Chris Ward" <cward@redhat.com>
 
+'''
+
+.. note::
+    example date ranges: 'd', '~d', 'd~', 'd~d'
+
+.. note::
+    valid date format: '%Y-%m-%d %H:%M:%S,%f', '%Y-%m-%d %H:%M:%S', '%Y-%m-%d'
+
+'''
+
 import logging
 logger = logging.getLogger(__name__)
 import os
@@ -13,8 +23,7 @@ from metrique.config import DEFAULT_CONFIG_DIR, DEFAULT_CONFIG_FILE
 from metrique import query_api, etl_api, users_api
 from metrique import etl_activity, get_cube
 
-from metrique.utils import csv2list
-from metrique.json import json_encode
+from metrique.utils import csv2list, json_encode
 
 
 class HTTPClient(object):
@@ -26,10 +35,10 @@ class HTTPClient(object):
 
     find = query_api.find
     deptree = query_api.deptree
-    tree = query_api.deptree
     count = query_api.count
     fetch = query_api.fetch
     distinct = query_api.distinct
+    sample = query_api.sample
     aggregate = query_api.aggregate
     list_index = etl_api.list_index
     ensure_index = etl_api.ensure_index
@@ -45,29 +54,34 @@ class HTTPClient(object):
         Return the specific cube class, if specified
         '''
         if 'cube' in kwargs and kwargs['cube']:
-            _cube = kwargs['cube']
-            kwargs['cube'] = None
-            cube_cls = get_cube(_cube)
-            return object.__new__(cube_cls, *args, **kwargs)
+            try:
+                cube_cls = get_cube(kwargs['cube'])
+            except ImportError:
+                cube_cls = cls
         else:
-            return object.__new__(cls, *args, **kwargs)
+            cube_cls = cls
+        return object.__new__(cube_cls, *args, **kwargs)
 
-    def __init__(self, host=None, username=None, password=None,
-                 async=True, force=False, debug=-1,
-                 config_file=None, config_dir=None,
-                 cube=None, **kwargs):
+    def __init__(self, api_host=None, api_username=None,
+                 api_password=None, async=True,
+                 force=False, debug=-1, config_file=None,
+                 config_dir=None, cube=None,
+                 **kwargs):
         self.load_config(config_file, config_dir, force)
         logging.basicConfig()
         self.logger = logging.getLogger('metrique.%s' % self.__module__)
         self.config.debug = self.logger, debug
         self.config.async = async
 
-        if host:
-            self.config.api_host = host
-        if username:
-            self.config.api_username = username
-        if password:
-            self.config.api_password = password
+        if cube and not self.name and isinstance(cube, basestring):
+            self.name = cube
+
+        if api_host:
+            self.config.api_host = api_host
+        if api_username:
+            self.config.api_username = api_username
+        if api_password:
+            self.config.api_password = api_password
 
     def load_config(self, config_file, config_dir, force=False):
         if not config_file:
@@ -112,8 +126,8 @@ class HTTPClient(object):
 
     def _post(self, *args, **kwargs):
         '''
-            Arguments are expected to be json encoded!
-            verify = False in requests.get() skips SSL CA validation
+        Arguments are expected to be json encoded!
+        verify = False in requests.get() skips SSL CA validation
         '''
         kwargs_json = self._kwargs_json(**kwargs)
         _url = self._args_url(*args)
@@ -158,15 +172,14 @@ class HTTPClient(object):
 
     def list_cube_fields(self, cube=None,
                          exclude_fields=None, _mtime=False):
-        ''' List all valid fields for a given cube
+        '''
+        List all valid fields for a given cube
 
-        Paremeters
-        ----------
-        cube : str
+        :param string cube:
             Name of the cube you want to query
-        exclude_fields : str or list
+        :param list exclude_fields:
             List (or csv) of fields to exclude from the results
-        mtime : bool
+        :param bool mtime:
             Include mtime details
         '''
         if not cube:
